==> jc-1.4.0.tar.gz: org/dellroad/jc/Generate.h <==
// public final class org.dellroad.jc.Generate

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class feb4dae098e0a543 org_dellroad_jc_Generate

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_Generate_H_
#define _JC_org_dellroad_jc_Generate_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_Generate$object;
struct _jc_org_dellroad_jc_ObjectGenerator$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_Generate$sub_refs	_jc_org_dellroad_jc_Generate$sub_refs;
typedef struct _jc_org_dellroad_jc_Generate$sub_nonrefs	_jc_org_dellroad_jc_Generate$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_Generate$refs	_jc_org_dellroad_jc_Generate$refs;
typedef struct _jc_org_dellroad_jc_Generate$nonrefs	_jc_org_dellroad_jc_Generate$nonrefs;
typedef struct _jc_org_dellroad_jc_Generate$object	_jc_org_dellroad_jc_Generate$object;

typedef struct _jc_org_dellroad_jc_Generate$fields_struct	_jc_org_dellroad_jc_Generate$fields_struct;
typedef const struct _jc_org_dellroad_jc_Generate$vmethods	_jc_org_dellroad_jc_Generate$vmethods;
typedef const struct _jc_org_dellroad_jc_Generate$vtable	_jc_org_dellroad_jc_Generate$vtable;
typedef const struct _jc_org_dellroad_jc_Generate$vtype	_jc_org_dellroad_jc_Generate$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_Generate$fields_struct {
	struct _jc_org_dellroad_jc_Generate$object	*instance;
	struct _jc_java_lang_String$object	*objectDir;
	jchar	FILE__5fSEPARATOR;
	jchar	PATH__5fSEPARATOR;
};
extern _jc_org_dellroad_jc_Generate$fields_struct _jc_org_dellroad_jc_Generate$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_Generate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_Generate$method$generateObject$81b546039a9826d2(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_Generate$method_info$generateObject$81b546039a9826d2;

// Static methods
extern void _jc_org_dellroad_jc_Generate$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$decode$064bfd341c457426(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$encode$771f3a53468a38d5(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$encode$b8eb8e162a0d6997(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern jlong _jc_org_dellroad_jc_Generate$method$hash$f469108c80a86320(_jc_env *, struct _jc_java_io_InputStream$object *);
extern struct _jc_java_io_File$object *_jc_org_dellroad_jc_Generate$method$objectFile$38216f62f915b6d1(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_io_File$object *_jc_org_dellroad_jc_Generate$method$objectFile$aaaa39f0b0341d0d(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_io_File$object *);
extern struct _jc_org_dellroad_jc_Generate$object *_jc_org_dellroad_jc_Generate$method$v$fc656119293b15fb(_jc_env *);

// Virtual methods structure
struct _jc_org_dellroad_jc_Generate$vmethods {
	void	(*generateObject$81b546039a9826d2)(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);
};

// Vtable
struct _jc_org_dellroad_jc_Generate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_Generate$vmethods	org_dellroad_jc_Generate;
};

// Vtype
struct _jc_org_dellroad_jc_Generate$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_Generate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_Generate$sub_refs {
	struct _jc_object	*generator;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_Generate$refs {
    _jc_org_dellroad_jc_Generate$sub_refs	org_dellroad_jc_Generate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_Generate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_Generate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_Generate$sub_nonrefs	org_dellroad_jc_Generate;
};

// Object instance structure
struct _jc_org_dellroad_jc_Generate$object {
	_jc_org_dellroad_jc_Generate$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_Generate$vtype	*vtype;
	_jc_org_dellroad_jc_Generate$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_Generate$vtype _jc_org_dellroad_jc_Generate$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_Generate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_Generate$class_object;

#endif	/* _JC_org_dellroad_jc_Generate_H_ */

==> jc-1.4.5.tar.gz: org/dellroad/jc/Generate.h <==
// public final class org.dellroad.jc.Generate

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class feb4dae098e0a543 org_dellroad_jc_Generate

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_Generate_H_
#define _JC_org_dellroad_jc_Generate_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_Generate$object;
struct _jc_org_dellroad_jc_ObjectGenerator$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_Generate$sub_refs	_jc_org_dellroad_jc_Generate$sub_refs;
typedef struct _jc_org_dellroad_jc_Generate$sub_nonrefs	_jc_org_dellroad_jc_Generate$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_Generate$refs	_jc_org_dellroad_jc_Generate$refs;
typedef struct _jc_org_dellroad_jc_Generate$nonrefs	_jc_org_dellroad_jc_Generate$nonrefs;
typedef struct _jc_org_dellroad_jc_Generate$object	_jc_org_dellroad_jc_Generate$object;

typedef struct _jc_org_dellroad_jc_Generate$fields_struct	_jc_org_dellroad_jc_Generate$fields_struct;
typedef const struct _jc_org_dellroad_jc_Generate$vmethods	_jc_org_dellroad_jc_Generate$vmethods;
typedef const struct _jc_org_dellroad_jc_Generate$vtable	_jc_org_dellroad_jc_Generate$vtable;
typedef const struct _jc_org_dellroad_jc_Generate$vtype	_jc_org_dellroad_jc_Generate$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_Generate$fields_struct {
	struct _jc_org_dellroad_jc_Generate$object	*instance;
	struct _jc_java_lang_String$object	*objectDir;
	jchar	FILE__5fSEPARATOR;
	jchar	PATH__5fSEPARATOR;
};
extern _jc_org_dellroad_jc_Generate$fields_struct _jc_org_dellroad_jc_Generate$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_Generate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_Generate$method$generateObject$81b546039a9826d2(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_Generate$method_info$generateObject$81b546039a9826d2;

// Static methods
extern void _jc_org_dellroad_jc_Generate$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$decode$064bfd341c457426(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$encode$771f3a53468a38d5(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_Generate$method$encode$b8eb8e162a0d6997(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern jlong _jc_org_dellroad_jc_Generate$method$hash$f469108c80a86320(_jc_env *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_File$object *_jc_org_dellroad_jc_Generate$method$objectFile$38216f62f915b6d1(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_File$object *_jc_org_dellroad_jc_Generate$method$objectFile$aaaa39f0b0341d0d(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_org_dellroad_jc_Generate$object *_jc_org_dellroad_jc_Generate$method$v$fc656119293b15fb(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_Generate$vmethods {
	void	(*generateObject$81b546039a9826d2)(_jc_env *, struct _jc_org_dellroad_jc_Generate$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_Generate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_Generate$vmethods	org_dellroad_jc_Generate;
};

// Vtype
struct _jc_org_dellroad_jc_Generate$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_Generate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_Generate$sub_refs {
	struct _jc_object	*generator;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_Generate$refs {
    _jc_org_dellroad_jc_Generate$sub_refs	org_dellroad_jc_Generate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_Generate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_Generate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_Generate$sub_nonrefs	org_dellroad_jc_Generate;
};

// Object instance structure
struct _jc_org_dellroad_jc_Generate$object {
	_jc_org_dellroad_jc_Generate$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_Generate$vtype	*vtype;
	_jc_org_dellroad_jc_Generate$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_Generate$vtype _jc_org_dellroad_jc_Generate$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_Generate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_Generate$class_object;

#endif	/* _JC_org_dellroad_jc_Generate_H_ */
